Module fp

Module fp 

Compressed static maps based on fingerprinting.

Modules

collision_solver
level_size_chooser

Structs

Bits
Size in bits.
Bits8
Seed size of 8 bits.
CMap
Finger-printing based compressed static function (immutable map) that maps hashable keys to values of any type.
CMapConf
Configuration accepted by fp::CMap constructors.
GOCMap
Finger-printing based compressed static function (immutable map) that uses group optimization and maps hashable keys to values of any type.
GOCMapConf
Configuration accepted by fp::GOCMap constructors.
GOConf
Configuration of family of (group-optimized) hash functions used by GOFunction and accepted by GOBuildConf constructors.
LoMemAcceptEquals
Map
Finger-printing based static function (immutable map) that maps hashable keys to unsigned integer values of given bit-size.
MapConf
Configuration accepted by fp::Map constructors.
OptimalLevelSize
Chooses optimal level size considering distribution of incidence of values.
ProportionalLevelSize
Choose level size as a percent of the input size.
ResizedLevel
Resize level obtained from another chooser.
TwoToPowerBits
Size being the power of two.
TwoToPowerBitsStatic
Seed size given as a power of two (knowing at compile time).

Traits

CollisionSolver
Solves value collisions during construction of BBMap.
CollisionSolverBuilder
Builds CollisionSolver.
GroupSize
Implementations of GroupSize represent group size in fingerprinting-based minimal perfect hashing with group optimization.
IsLossless
Shows that the builder always produces the collision solver that is lossless and thus can be used with compressed BBmap.
LevelSizeChooser
Chooses the size of level for the given level input.
SeedSize
Implementations of SeedSize represent seed size in fingerprinting-based minimal perfect hashing with group optimization.
SimpleLevelSizeChooser