HyperGraph

Struct HyperGraph 

pub struct HyperGraph<VertexIndex, Values> { /* private fields */ }
3-regular hyper-graph.

Implementations

Source

impl<VI> HyperGraph<VI, ()>
where VI: VertexIndex,

pub fn new(number_of_vertices: usize) -> HyperGraph<VI, ()>

Constructs hyper-graph with the given number_of_vertices.

pub fn add_edge(&mut self, a: usize, b: usize, c: usize)

Adds (a, b, c) edge to self.

pub fn peel(self, number_of_edges: usize) -> Vec<(VI, VI, VI)>

Returns a sequence of the graph edges v0=(a0, b0, c0), v1=(a1, b1, c1), … such that the vertex ai is not incident to the edge vj for all j>i.

Source

impl<VI> HyperGraph<VI, PackedInts>
where VI: VertexIndex,

pub fn with_bits_per_value( number_of_vertices: usize, bits_per_value: u8, ) -> HyperGraph<VI, PackedInts>

Constructs hyper-graph with the given number_of_vertices whose can have assigned values of a given bit-size.

Source

impl<VI, Values> HyperGraph<VI, Values>
where VI: VertexIndex, Values: EdgeValues,

pub fn with_values( number_of_vertices: usize, values: Values, ) -> HyperGraph<VI, Values>

pub fn add_edge_with_value( &mut self, a: usize, b: usize, c: usize, value: <Values as EdgeValues>::Value, )

Adds to self the edge (a, b, c) with assigned value.

pub fn peel_with_values<VC>( self, number_of_edges: usize, value_consumer: VC, ) -> Vec<(VI, VI, VI)>
where VC: FnMut(&<Values as EdgeValues>::Value),

Returns a sequence of the graph edges v0=(a0, b0, c0), v1=(a1, b1, c1), … such that the vertex ai is not incident to the edge vj for all j>i. Call value_consumer for each value assigned to the edge pushed to the returned sequence.