CMap

Struct CMap 

pub struct CMap<C, S = BuildWyHash> {
    pub value_fragments: Map<S>,
    pub value_coding: C,
}
Compressed static function (immutable map) that maps hashable keys to values of any type.

To represent a function f:X→Y, it uses the space slightly larger than |X|H (the overhead is 23% or slightly more), where H is the entropy of the distribution of the f values over X. The time complexity is O(c) for evaluation and O(|X|c) for construction (not counting building the encoding dictionary), where c is the average codeword length (given in code fragments) of the values.

It uses Map based on solving linear system to store fragments of value codes and usually minimum_redundancy::Coding to compress values.

Fields

value_fragments: Map<S>value_coding: C

Implementations

Source

impl<C, S> CMap<C, S>

pub fn write_bytes(&self, bytes_per_value: usize) -> usize

Returns the number of bytes which write will write, assuming that each call to write_value writes bytes_per_value bytes.

pub fn write<F>( &self, output: &mut dyn Write, write_value: F, ) -> Result<(), Error>
where F: FnMut(&mut dyn Write, &<C as Coding>::Value) -> Result<(), Error>,

Writes self to the output using write_value to write values.

pub fn read_with_hasher<F>( input: &mut dyn Read, read_value: F, hasher: S, ) -> Result<CMap<C, S>, Error>
where F: FnMut(&mut dyn Read) -> Result<<C as Coding>::Value, Error>,

Reads self from the input, using read_value to read values (hasher must be the same as used by stored BDZHMap).

Source

impl<C> CMap<C, BuildHasherDefault<DefaultHasher>>

pub fn read<F>( input: &mut dyn Read, read_value: F, ) -> Result<CMap<C, BuildHasherDefault<DefaultHasher>>, Error>
where F: FnMut(&mut dyn Read) -> Result<<C as Coding>::Value, Error>,

Reads BDZHMap from the input using read_value to read values. Only BDZHMaps that use default hasher can be read by this method.

Source

impl<C, S> CMap<C, S>

pub fn try_from_mapf_with_coding_conf<'a, K, V, KvIntoIter, FKvIntoIter, BM>( map: FKvIntoIter, value_coding: C, conf: MapConf<BM, S>, extra_bits_per_fragment: u8, ) -> Option<CMap<C, S>>
where K: Hash + 'a, V: Borrow<<C as Coding>::Value> + 'a, KvIntoIter: IntoIterator<Item = (&'a K, &'a V)> + 'a, FKvIntoIter: Fn() -> KvIntoIter, BM: ValuesPreFiller,

Underlying Map uses value_coding.bits_per_fragment()+extra_bits_per_fragment bits per fragment. extra_bits_per_fragment>0 increases a chance of detection absence of the key by get and get_stats.

pub fn try_from_map_with_coding_conf<K, MS, BM, V>( map: &HashMap<K, V, MS>, value_coding: C, conf: MapConf<BM, S>, bdz_extra_bits_per_fragment: u8, ) -> Option<CMap<C, S>>
where K: Hash, BM: ValuesPreFiller, V: Borrow<<C as Coding>::Value>,

pub fn try_from_kv_with_coding_conf<K, BM, V>( keys: &[K], values: &[V], value_coding: C, conf: MapConf<BM, S>, bdz_extra_bits_per_fragment: u8, ) -> Option<CMap<C, S>>
where K: Hash, BM: ValuesPreFiller, V: Borrow<<C as Coding>::Value>,

Source

impl<C> CMap<C>
where C: Coding,

pub fn try_from_map_with_coding<K, MS, V>( map: &HashMap<K, V, MS>, value_coding: C, bdz_extra_bits_per_fragment: u8, ) -> Option<CMap<C>>
where K: Hash, V: Borrow<<C as Coding>::Value>,

pub fn try_from_mapf_with_coding<'a, K, KvIntoIter, FKvIntoIter, V>( map: FKvIntoIter, value_coding: C, bdz_extra_bits_per_fragment: u8, ) -> Option<CMap<C>>
where K: Hash + 'a, V: Borrow<<C as Coding>::Value> + 'a, KvIntoIter: IntoIterator<Item = (&'a K, &'a V)> + 'a, FKvIntoIter: Fn() -> KvIntoIter,

pub fn try_from_kv_with_coding<K, V>( keys: &[K], values: &[V], value_coding: C, bdz_extra_bits_per_fragment: u8, ) -> Option<CMap<C>>
where K: Hash, V: Borrow<<C as Coding>::Value>,

Source

impl<C, S> CMap<C, S>

pub fn try_from_map_with_builder_bpf_conf<K, MS, BM, BC>( map: &HashMap<K, <C as Coding>::Value, MS>, build_coding: &BC, bits_per_fragment: u8, conf: MapConf<BM, S>, bdz_extra_bits_per_fragment: u8, ) -> Option<CMap<C, S>>
where K: Hash, BM: ValuesPreFiller, BC: BuildCoding<<C as Coding>::Value, Coding = C>,

pub fn try_from_map_with_builder_conf<K, MS, BM, BC>( map: &HashMap<K, <C as Coding>::Value, MS>, build_coding: &BC, conf: MapConf<BM, S>, bdz_extra_bits_per_fragment: u8, ) -> Option<CMap<C, S>>
where K: Hash, BM: ValuesPreFiller, BC: BuildCoding<<C as Coding>::Value, Coding = C>,

pub fn try_from_kv_with_builder_bpf_conf<K, BM, BC>( keys: &[K], values: &[<C as Coding>::Value], build_coding: &BC, bits_per_fragment: u8, conf: MapConf<BM, S>, bdz_extra_bits_per_fragment: u8, ) -> Option<CMap<C, S>>
where K: Hash, BM: ValuesPreFiller, BC: BuildCoding<<C as Coding>::Value, Coding = C>,

pub fn try_from_kv_with_builder_conf<K, BM, BC>( keys: &[K], values: &[<C as Coding>::Value], build_coding: &BC, conf: MapConf<BM, S>, bdz_extra_bits_per_fragment: u8, ) -> Option<CMap<C, S>>
where K: Hash, BM: ValuesPreFiller, BC: BuildCoding<<C as Coding>::Value, Coding = C>,

Source

impl<V, S> CMap<Coding<V>, S>
where V: Hash + Eq + Clone, S: BuildSeededHasher,

pub fn try_from_map_with_conf<K, MS, BM>( map: &HashMap<K, V, MS>, bits_per_fragment: u8, conf: MapConf<BM, S>, bdz_extra_bits_per_fragment: u8, ) -> Option<CMap<Coding<V>, S>>
where K: Hash, BM: ValuesPreFiller,

pub fn try_from_kv_with_conf<K, BM>( keys: &[K], values: &[V], bits_per_fragment: u8, conf: MapConf<BM, S>, bdz_extra_bits_per_fragment: u8, ) -> Option<CMap<Coding<V>, S>>
where K: Hash, BM: ValuesPreFiller,

Source

impl<V> CMap<Coding<V>>
where V: Hash + Eq + Clone,

pub fn try_from_map<K, MS>( map: &HashMap<K, V, MS>, bits_per_fragment: u8, bdz_extra_bits_per_fragment: u8, ) -> Option<CMap<Coding<V>>>
where K: Hash,

pub fn try_from_mapf<'a, K, KvIntoIter, FKvIntoIter, BM>( map: FKvIntoIter, bits_per_fragment: u8, bdz_extra_bits_per_fragment: u8, ) -> Option<CMap<Coding<V>>>
where K: Hash + 'a, V: 'a, KvIntoIter: IntoIterator<Item = (&'a K, &'a V)> + 'a, FKvIntoIter: Fn() -> KvIntoIter,

pub fn try_from_kv<K>( keys: &[K], values: &[V], bits_per_fragment: u8, bdz_extra_bits_per_fragment: u8, ) -> Option<CMap<Coding<V>>>
where K: Hash,

Source

impl<C, S> CMap<C, S>

pub fn get_stats<K, A>( &self, k: &K, access_stats: &mut A, ) -> Option<<<C as Coding>::Decoder<'_> as Decoder>::Decoded>

Gets the value associated with the given key k and reports statistics to access_stats.

pub fn get<K>( &self, k: &K, ) -> Option<<<C as Coding>::Decoder<'_> as Decoder>::Decoded>
where K: Hash + ?Sized,

Gets the value associated with the given key k.