Module transposition_table

Module transposition_table 

Re-exports

pub use crate::dbs::NimbersProvider;
pub use crate::dbs::NimbersStorer;

Modules

bit_mixer
cluster_policy

Structs

ClusterConf
Clusters configuration.
ProtectedTT
Transposition Table that protects nimbers of some positions (usually the positions that are close to a root of a search tree).
TTSuccinct64
Succinct transposition table for 64-bit positions.

Traits

ClusterPolicy
Clusters update and lookup policy. The module cluster_policy includes many implementations.